"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cliOptions = void 0;
const conventional_cli_1 = require("conventional-cli");
const models_1 = require("./../models");
const core_1 = require("./../../core");
const enums_1 = require("./../enums");
const cliOptions = [
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.project,
        longName: enums_1.OptionsLongNames.project,
        required: true,
        type: conventional_cli_1.ArgumentTypes.glob,
        description: `The path to project folder`,
        additionalDescription: ``,
        default: core_1.config.defaultValues.projectPath,
        values: [
            enums_1.OptionsPath.relative,
            enums_1.OptionsPath.absolute
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.languages,
        longName: enums_1.OptionsLongNames.languages,
        required: true,
        type: conventional_cli_1.ArgumentTypes.glob,
        description: `The path to languages folder`,
        additionalDescription: ``,
        default: core_1.config.defaultValues.languagesPath,
        values: [
            enums_1.OptionsPath.relative,
            enums_1.OptionsPath.absolute
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.keysOnViews,
        longName: enums_1.OptionsLongNames.keysOnViews,
        required: false,
        type: conventional_cli_1.ArgumentTypes.enum,
        description: `Described how to handle the error of missing keys on view`,
        additionalDescription: ``,
        default: core_1.ErrorTypes.error,
        values: [
            core_1.ErrorTypes.disable,
            core_1.ErrorTypes.warning,
            core_1.ErrorTypes.error
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.zombieKeys,
        longName: enums_1.OptionsLongNames.zombieKeys,
        required: false,
        type: conventional_cli_1.ArgumentTypes.enum,
        description: `Described how to handle the error of zombies keys`,
        additionalDescription: ``,
        default: core_1.ErrorTypes.warning,
        values: [
            core_1.ErrorTypes.disable,
            core_1.ErrorTypes.warning,
            core_1.ErrorTypes.error
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.emptyKeys,
        longName: enums_1.OptionsLongNames.emptyKeys,
        required: false,
        type: conventional_cli_1.ArgumentTypes.enum,
        description: `Described how to handle empty value on translate keys`,
        additionalDescription: ``,
        default: core_1.ErrorTypes.warning,
        values: [
            core_1.ErrorTypes.disable,
            core_1.ErrorTypes.warning,
            core_1.ErrorTypes.error
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.ignore,
        longName: enums_1.OptionsLongNames.ignore,
        required: false,
        type: conventional_cli_1.ArgumentTypes.glob,
        description: `Ignore projects and languages files`,
        additionalDescription: ``,
        values: [
            enums_1.OptionsPath.relative,
            enums_1.OptionsPath.absolute
        ]
    }),
    new models_1.OptionModel({
        longName: enums_1.OptionsLongNames.maxWarning,
        required: false,
        type: conventional_cli_1.ArgumentTypes.glob,
        description: `Max count of warnings in all files. If this value more that count of warnings, then an error is return`,
        additionalDescription: ``,
        default: core_1.config.defaultValues.rules.maxWarning.toString(),
        values: [
            conventional_cli_1.ArgumentTypes.number,
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.misprintKeys,
        longName: enums_1.OptionsLongNames.misprintKeys,
        required: false,
        type: conventional_cli_1.ArgumentTypes.enum,
        description: `Try to find matches with misprint keys on views and languages keys. Coefficient: 0.9. Can be longer process!!`,
        additionalDescription: ``,
        default: core_1.ErrorTypes.disable,
        values: [
            core_1.ErrorTypes.disable,
            core_1.ErrorTypes.warning,
            core_1.ErrorTypes.error
        ]
    }),
    new models_1.OptionModel({
        shortName: enums_1.OptionsShortNames.deepSearch,
        longName: enums_1.OptionsLongNames.deepSearch,
        required: false,
        type: conventional_cli_1.ArgumentTypes.enum,
        description: `Add each translate key to global regexp end try to find them on project. Can be longer process!!`,
        additionalDescription: ``,
        default: core_1.ToggleRule.disable,
        values: [
            core_1.ToggleRule.disable,
            core_1.ToggleRule.enable,
        ]
    }),
    new models_1.OptionModel({
        longName: enums_1.OptionsLongNames.misprintCoefficient,
        shortName: enums_1.OptionsShortNames.misprintCoefficient,
        required: false,
        type: conventional_cli_1.ArgumentTypes.number,
        description: `Coefficient for misprint option can be from 0 to 1.0.`,
        additionalDescription: ``,
        default: core_1.config.defaultValues.rules.misprintCoefficient.toString(),
    }),
    new models_1.OptionModel({
        longName: enums_1.OptionsLongNames.config,
        shortName: enums_1.OptionsShortNames.config,
        required: false,
        type: conventional_cli_1.ArgumentTypes.path,
        description: `Path to config`,
        additionalDescription: ``,
        values: [
            enums_1.OptionsPath.relative,
            enums_1.OptionsPath.absolute
        ]
    }),
    new models_1.OptionModel({
        longName: enums_1.OptionsLongNames.version,
        shortName: enums_1.OptionsShortNames.version,
        required: false,
        description: 'Print current version of react-i18next-lint',
        type: conventional_cli_1.ArgumentTypes.undefined,
        additionalDescription: '',
    }),
];
exports.cliOptions = cliOptions;
//# sourceMappingURL=CliOptions.js.map