"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReactI18nextLint = void 0;
const lodash_1 = require("lodash");
const path = __importStar(require("path"));
const config_1 = require("./config");
const enums_1 = require("./enums");
const utils_1 = require("./utils");
const models_1 = require("./models");
const rules_1 = require("./rules");
const KeyModelWithLanguages_1 = require("./models/KeyModelWithLanguages");
class ReactI18nextLint {
    constructor(projectPath = config_1.config.defaultValues.projectPath, languagesPath = config_1.config.defaultValues.languagesPath, ignore, rulesConfig = config_1.config.defaultValues.rules, tsConfigPath) {
        this.languagesPath = languagesPath;
        this.projectPath = projectPath;
        this.ignore = ignore;
        this.rules = rulesConfig;
        this.tsConfigPath = tsConfigPath;
    }
    lint(maxWarning) {
        var _a;
        if (!(this.projectPath && this.languagesPath)) {
            throw new Error(`Path to project or languages is incorrect`);
        }
        if (!('zombieKeys' in this.rules)) {
            throw new Error('Error config is incorrect');
        }
        const languagesKeys = new models_1.FileLanguageModel(this.languagesPath, [], [], this.ignore).getKeysWithValue();
        const languagesKeysNames = (0, lodash_1.flatMap)(languagesKeys.keys, (key) => key.name);
        const viewsRegExp = utils_1.KeysUtils.findKeysList(languagesKeysNames, this.rules.customRegExpToFindKeys, this.rules.deepSearch);
        const views = new models_1.FileViewModel(this.projectPath, [], [], this.ignore).getKeys(viewsRegExp);
        let errors = [];
        if (this.rules.zombieKeys !== enums_1.ErrorTypes.disable ||
            this.rules.keysOnViews !== enums_1.ErrorTypes.disable ||
            this.rules.misprintKeys !== enums_1.ErrorTypes.disable ||
            this.rules.emptyKeys !== enums_1.ErrorTypes.disable) {
            const regExpResult = this.runRegExp(views, languagesKeys);
            errors.push(...regExpResult);
        }
        if (((_a = this.rules.ignoredKeys) === null || _a === void 0 ? void 0 : _a.length) !== 0) {
            errors = errors.reduce((acum, errorKey) => {
                const errorKeyValue = errorKey.value;
                if (!this.rules.ignoredKeys.some(ignoredKey => new RegExp(ignoredKey, "i").test(errorKeyValue))) {
                    const correctError = new models_1.ResultErrorModel(errorKey.value, errorKey.errorFlow, errorKey.errorType, errorKey.currentPath, errorKey.absentedPath, errorKey.suggestions);
                    acum.push(correctError);
                }
                return acum;
            }, []);
        }
        const cliResult = new models_1.ResultCliModel(errors, maxWarning);
        return cliResult;
    }
    getLanguages() {
        const result = [];
        const languagesFiles = new models_1.FileLanguageModel(this.languagesPath, [], [], this.ignore);
        const languagesKeys = languagesFiles.getKeysWithValue();
        if (languagesKeys.keys.length === 0) {
            languagesFiles.files.forEach((filePath) => {
                const languageName = path.basename(filePath, '.json');
                const languageModel = new models_1.LanguagesModel(languageName);
                languageModel.path = filePath;
                result.push(languageModel);
            });
        }
        languagesKeys.keys.forEach((key) => {
            key.languages.forEach((languagePath) => {
                const name = path.basename(languagePath);
                const languageIndex = result.findIndex((x) => x.name === name);
                if (languageIndex === -1) {
                    const language = new models_1.LanguagesModel(name);
                    language.path = languagePath;
                    language.keys.push(key);
                    result.push(language);
                }
                else {
                    result[languageIndex].keys.push(key);
                }
            });
        });
        if (this.projectPath) {
            const languagesKeysNames = (0, lodash_1.flatMap)(languagesKeys.keys, (key) => key.name);
            const viewsRegExp = utils_1.KeysUtils.findKeysList(languagesKeysNames, this.rules.customRegExpToFindKeys);
            const views = new models_1.FileViewModel(this.projectPath, [], [], this.ignore).getKeys(viewsRegExp);
            views.keys.forEach((key) => {
                result.forEach((language) => {
                    const keyIndex = language.keys.findIndex((x) => x.name === key.name);
                    if (keyIndex !== -1) {
                        language.keys[keyIndex].views = key.views;
                    }
                });
            });
        }
        return result;
    }
    getKeys() {
        const result = [];
        const languagesKeys = this.getLanguages();
        languagesKeys.forEach((language) => {
            language.keys.forEach((key) => {
                const isKeyExistIndex = result.findIndex(x => x.name === key.name);
                if (isKeyExistIndex === -1) {
                    const viewsModels = key.views.map((x) => {
                        return new KeyModelWithLanguages_1.ViewModelWithKey(x);
                    });
                    const languagesModel = new KeyModelWithLanguages_1.LanguagesModelWithKey(language.name, language.path, key.value);
                    const keyModel = new KeyModelWithLanguages_1.KeyModelWithLanguages(key.name, [languagesModel], viewsModels);
                    result.push(keyModel);
                }
                else {
                    const currentKeyModel = result[isKeyExistIndex];
                    const viewsModels = key.views.map((x) => {
                        return new KeyModelWithLanguages_1.ViewModelWithKey(x);
                    });
                    const languagesModel = new KeyModelWithLanguages_1.LanguagesModelWithKey(language.name, language.path, key.value);
                    currentKeyModel.languages.push(languagesModel);
                    currentKeyModel.views.push(...viewsModels);
                }
            });
        });
        return result;
    }
    runRegExp(views, languagesKeys, rules = this.rules) {
        const result = [];
        if (rules.zombieKeys !== enums_1.ErrorTypes.disable) {
            const ruleInstance = new rules_1.ZombieRule(this.rules.zombieKeys);
            const ruleResult = ruleInstance.check(views.keys, languagesKeys.keys);
            result.push(...ruleResult);
        }
        if (rules.keysOnViews !== enums_1.ErrorTypes.disable) {
            const ruleInstance = new rules_1.AbsentViewKeysRule(this.rules.keysOnViews, languagesKeys.files);
            const ruleResult = ruleInstance.check(views.keys, languagesKeys.keys);
            result.push(...ruleResult);
        }
        if (rules.misprintKeys !== enums_1.ErrorTypes.disable) {
            const ruleInstance = new rules_1.MisprintRule(this.rules.misprintKeys, this.rules.misprintCoefficient, this.rules.ignoredMisprintKeys);
            const ruleResult = ruleInstance.check(result, languagesKeys.keys);
            result.push(...ruleResult);
        }
        if (rules.emptyKeys !== enums_1.ErrorTypes.disable) {
            const ruleInstance = new rules_1.EmptyKeysRule(this.rules.emptyKeys);
            const ruleResult = ruleInstance.check(languagesKeys.keys);
            result.push(...ruleResult);
        }
        return result;
    }
}
exports.ReactI18nextLint = ReactI18nextLint;
//# sourceMappingURL=client.js.map