"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileLanguageModel = void 0;
const lodash_1 = require("lodash");
const KeyModel_1 = require("../KeyModel");
const FileModel_1 = require("./FileModel");
class FileLanguageModel extends FileModel_1.FileModel {
    constructor(path, files = [], keys = [], ignore = '') {
        super(path, files, keys, ignore);
    }
    getKeys() {
        this.files = this.getNormalizeFiles();
        this.keys = this.parseKeys((fileData, filePath) => {
            try {
                const fileKeysNames = this.getLanguageKeys(JSON.parse(fileData));
                return !fileKeysNames ? [] : fileKeysNames
                    .filter(x => !!x)
                    .map((key) => {
                    return new KeyModel_1.KeyModel(key, [], [filePath]);
                });
            }
            catch (e) {
                const errorMessage = `Can't parse JSON file: ${filePath}`;
                throw new Error(errorMessage);
            }
        });
        return this;
    }
    getKeysWithValue() {
        this.files = this.getNormalizeFiles();
        this.keys = this.parseKeysWithValues((fileData, filePath) => {
            try {
                const fileKeysNames = this.getLanguageKeysWithValue(JSON.parse(fileData));
                return fileKeysNames.map((key) => {
                    key.languages.push(filePath);
                    return key;
                });
            }
            catch (e) {
                const errorMessage = `Can't parse JSON file: ${filePath}`;
                throw new Error(errorMessage);
            }
        });
        return this;
    }
    getLanguageKeysWithValue(obj, cat = null, tKeys = [], tValues = []) {
        const currentKeys = [...tKeys];
        const correctKeys = tValues;
        const objectKeys = Object.keys(obj);
        objectKeys.forEach((key) => {
            // @ts-ignore
            const keyValue = (0, lodash_1.get)(obj, key);
            const isObject = typeof keyValue === 'object';
            const currentKey = cat === null ? key : cat.concat('.', key);
            if (isObject) {
                const childKeys = this.getLanguageKeysWithValue(keyValue, currentKey, tKeys, correctKeys).map((x) => x.name);
                currentKeys.push(...childKeys);
            }
            else {
                correctKeys.push({
                    name: currentKey,
                    value: keyValue.toString(),
                    views: [],
                    languages: []
                });
            }
        });
        return correctKeys;
    }
    getLanguageKeys(obj, cat = null, tKeys = []) {
        const currentKeys = [...tKeys];
        const objectKeys = Object.keys(obj);
        objectKeys.forEach((key) => {
            // @ts-ignore
            const keyValue = (0, lodash_1.get)(obj, key);
            const isObject = typeof keyValue === 'object';
            const currentKey = cat === null ? key : cat.concat('.', key);
            if (isObject) {
                const childKeys = this.getLanguageKeys(keyValue, currentKey, tKeys);
                currentKeys.push(...childKeys);
            }
            else {
                currentKeys.push(currentKey);
            }
        });
        return currentKeys;
    }
}
exports.FileLanguageModel = FileLanguageModel;
//# sourceMappingURL=FileLanguageModel.js.map