"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResultCliModel = void 0;
const lodash_1 = require("lodash");
const utils_1 = require("../../utils");
const ResultModel_1 = require("./ResultModel");
const ResultFileModel_1 = require("./ResultFileModel");
const enums_1 = require("../../enums");
class ResultCliModel {
    constructor(errors = [], maxCountWarning = 0) {
        this.errors = [];
        this.maxCountWarning = 0;
        this.errors = errors;
        this.maxCountWarning = +maxCountWarning;
    }
    countWarnings() {
        const result = (this.errors.filter((item) => item.errorType === enums_1.ErrorTypes.warning) || []).length;
        return result;
    }
    hasWarnings() {
        const result = this.countWarnings() > 0;
        return result;
    }
    isFullOfWarning() {
        const result = this.maxCountWarning && this.maxCountWarning !== 0 && this.hasWarnings() ? this.countWarnings() > this.maxCountWarning : false;
        return result;
    }
    countErrors() {
        const result = (this.errors.filter((item) => item.errorType === enums_1.ErrorTypes.error) || []).length;
        return result;
    }
    hasErrors() {
        const result = this.countErrors() > 0 || this.isFullOfWarning();
        return result;
    }
    countMisprint() {
        const misprintCount = (this.errors.filter((item) => item.errorFlow === enums_1.ErrorFlow.misprintKeys) || []).length;
        return misprintCount;
    }
    hasMisprint() {
        const result = this.countMisprint() > 0;
        return result;
    }
    getEmptyKeys() {
        const result = (this.errors.filter((item) => item.errorFlow === enums_1.ErrorFlow.emptyKeys) || []);
        return result;
    }
    countEmptyKeys() {
        const result = (this.errors.filter((item) => item.errorFlow === enums_1.ErrorFlow.emptyKeys) || []).length;
        return result;
    }
    hasEmptyKeys() {
        const result = this.countEmptyKeys() > 0;
        return result;
    }
    exitCode() {
        return this.hasErrors() ? enums_1.StatusCodes.error : enums_1.StatusCodes.successful;
    }
    getResultFiles() {
        const resultFiles = (0, lodash_1.chain)(this.errors)
            .groupBy("currentPath")
            .map((dictionary, key) => {
            let clearDictionary = dictionary;
            const hasError = (0, lodash_1.some)(dictionary, { 'errorType': enums_1.ErrorTypes.error });
            const errorType = hasError || this.isFullOfWarning() ? enums_1.ErrorTypes.error : enums_1.ErrorTypes.warning;
            if (this.isFullOfWarning()) {
                clearDictionary = dictionary.map((item) => {
                    item.errorType = enums_1.ErrorTypes.error;
                    return item;
                });
            }
            return new ResultFileModel_1.ResultFileModel(key, clearDictionary, errorType);
        })
            .value();
        return resultFiles;
    }
    getResultModel() {
        const resultFiles = this.getResultFiles();
        const resultModel = new ResultModel_1.ResultModel(this, resultFiles, this.hasErrors(), this.hasWarnings(), utils_1.logger);
        return resultModel;
    }
}
exports.ResultCliModel = ResultCliModel;
//# sourceMappingURL=ResultCliModel.js.map