"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResultErrorModel = void 0;
const lodash_1 = require("lodash");
const enums_1 = require("../../enums");
class ResultErrorModel {
    constructor(value, errorFlow = enums_1.ErrorFlow.keysOnViews, errorType = enums_1.ErrorTypes.error, currentPath, absentedPath, suggestions = []) {
        this.value = value;
        this.errorFlow = errorFlow;
        this.errorType = errorType;
        this.currentPath = currentPath;
        this.absentedPath = absentedPath;
        this.suggestions = suggestions;
    }
    message() {
        let message = null;
        switch (this.errorFlow) {
            case enums_1.ErrorFlow.keysOnViews:
                message = (0, lodash_1.isArray)(this.absentedPath)
                    ? this.absentedPath.map((path) => `Key: '${this.value}' doesn't exist in '${path}'`)
                    : `Key: '${this.value}' doesn't exist in '${this.absentedPath}'`;
                break;
            case enums_1.ErrorFlow.zombieKeys:
                message = `Key: '${this.value}' doesn't exist in project'`;
                break;
            case enums_1.ErrorFlow.misprintKeys:
                message = this.suggestions.reduce((accum, item) => {
                    accum.push(`Possible match: '${item}' for key '${this.value}'`);
                    return accum;
                }, []);
                break;
            case enums_1.ErrorFlow.emptyKeys:
                message = `Key: '${this.value}' is empty in ${this.currentPath}`;
                break;
            default:
                message = 'Unknown error please write to the author';
                break;
        }
        return message;
    }
}
exports.ResultErrorModel = ResultErrorModel;
//# sourceMappingURL=ResultErrorModel.js.map