"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResultModel = void 0;
const lodash_1 = require("lodash");
const enums_1 = require("../../enums");
const StylishLogger_1 = require("../StylishLogger");
class ResultModel extends StylishLogger_1.StylishLogger {
    constructor(cliModel, files = [], hasError = false, hasWarning = false, logger = console) {
        super(logger, hasError ? enums_1.ErrorTypes.error : enums_1.ErrorTypes.warning);
        this.message = `Find missing translation keys in project`;
        this.cli = cliModel;
        this.files = files;
        this.hasError = hasError;
        this.hasWarning = hasWarning;
    }
    printResult() {
        if (this.files.length !== 0) {
            this.printMessage(`${this.message}\n`);
            this.files.forEach((file) => {
                this.printMessage(`\n\t${file.message()}\n`, file.errorType);
                file.errors.forEach((error) => {
                    (0, lodash_1.isArray)(error.message())
                        ? error.message().map((message) => {
                            this.printMessage(`\t\t${message}\n`, error.errorType);
                        })
                        : this.printMessage(`\t\t${error.message()}\n`, error.errorType);
                });
            });
        }
    }
    printSummery() {
        if (this.cli.hasWarnings() || this.cli.hasErrors()) {
            const totalErrorType = this.cli.isFullOfWarning() || this.cli.hasErrors() ? enums_1.ErrorTypes.error : enums_1.ErrorTypes.warning;
            const emptyKeys = this.cli.errors.filter((x) => x.errorFlow === enums_1.ErrorFlow.emptyKeys);
            const zombieKeys = this.cli.errors.filter((x) => x.errorFlow === enums_1.ErrorFlow.zombieKeys);
            const keysOnViews = this.cli.errors.filter((x) => x.errorFlow === enums_1.ErrorFlow.keysOnViews);
            const misprintKeys = this.cli.errors.filter((x) => x.errorFlow === enums_1.ErrorFlow.misprintKeys);
            this.printMessage(`\nFind following errors:`, totalErrorType);
            if (emptyKeys.length !== 0) {
                const errorType = this.cli.isFullOfWarning() ? enums_1.ErrorTypes.error : emptyKeys[0].errorType;
                this.printMessage(`Empty Keys: \t ${emptyKeys.length}`, errorType);
            }
            if (zombieKeys.length !== 0) {
                const errorType = this.cli.isFullOfWarning() ? enums_1.ErrorTypes.error : zombieKeys[0].errorType;
                this.printMessage(`Zombie Keys: \t ${zombieKeys.length}`, errorType);
            }
            if (keysOnViews.length !== 0) {
                const errorType = this.cli.isFullOfWarning() ? enums_1.ErrorTypes.error : keysOnViews[0].errorType;
                this.printMessage(`Key On Views: \t ${keysOnViews.length}`, errorType);
            }
            if (misprintKeys.length !== 0) {
                const errorType = this.cli.isFullOfWarning() ? enums_1.ErrorTypes.error : misprintKeys[0].errorType;
                this.printMessage(`Misprint Keys: \t ${misprintKeys.length}`, errorType);
            }
            this.printMessage(`--------------------`, totalErrorType);
            this.printMessage(`TOTAL: \t\t ${this.cli.countWarnings() + this.cli.countErrors()}`, totalErrorType);
            this.printMessage(`\n`);
        }
    }
}
exports.ResultModel = ResultModel;
//# sourceMappingURL=ResultModel.js.map