"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbsentViewKeysRule = void 0;
const path_1 = __importDefault(require("path"));
const lodash_1 = require("lodash");
const utils_1 = require("./../utils");
const enums_1 = require("./../enums");
const models_1 = require("./../models");
class AbsentViewKeysRule {
    constructor(handler = enums_1.ErrorTypes.error, languagesPathList) {
        this.flow = enums_1.ErrorFlow.keysOnViews;
        this.handler = handler;
        this.languagesPathList = languagesPathList;
    }
    languagesCount() {
        return this.languagesPathList.length;
    }
    check(viewsKeys, languagesKeys) {
        const keysList = utils_1.KeysUtils.groupKeysByName([...viewsKeys, ...languagesKeys]);
        const keysListError = keysList.filter((key) => !(key.languages.length === this.languagesCount()));
        const resultErrorList = keysListError.reduce((result, key) => {
            const resultErrors = key.views.map((viewPath) => {
                const absentLanguagePath = (0, lodash_1.differenceBy)(this.languagesPathList, key.languages)
                    .map((filePath) => path_1.default.basename(filePath));
                const resultErrorModel = new models_1.ResultErrorModel(key.name, this.flow, this.handler, viewPath, absentLanguagePath);
                return resultErrorModel;
            });
            result.push(...resultErrors);
            return result;
        }, []);
        return resultErrorList;
    }
}
exports.AbsentViewKeysRule = AbsentViewKeysRule;
//# sourceMappingURL=AbsentViewKeysRule.js.map