"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MisprintRule = void 0;
const string_similarity_1 = __importDefault(require("string-similarity"));
const enums_1 = require("./../enums");
const models_1 = require("./../models");
class MisprintRule {
    constructor(handler = enums_1.ErrorTypes.warning, coefficient = 0.9, ignoredMisprintKeys = []) {
        this.flow = enums_1.ErrorFlow.misprintKeys;
        this.ignoredMisprintKeys = [];
        this.handler = handler;
        this.maxCoefficient = coefficient;
        this.ignoredMisprintKeys = ignoredMisprintKeys;
    }
    check(viewErrorsKeys, languagesKeys) {
        const languagesKeysList = languagesKeys.map((key) => key.name);
        const resultErrorList = viewErrorsKeys.reduce((result, key) => {
            if (this.ignoredMisprintKeys.includes(key.value)) {
                return result;
            }
            const bestMatchModel = string_similarity_1.default.findBestMatch(key.value, languagesKeysList);
            const bestMatchIndex = bestMatchModel.bestMatch.rating >= this.maxCoefficient ? bestMatchModel.bestMatchIndex : -1;
            if (bestMatchIndex !== -1 && languagesKeys[bestMatchIndex].name !== key.value) {
                const error = new models_1.ResultErrorModel(key.value, this.flow, this.handler, key.currentPath, key.absentedPath, [
                    `${languagesKeys[bestMatchIndex].name}`
                ]);
                result.push(error);
            }
            return result;
        }, []);
        return resultErrorList;
    }
}
exports.MisprintRule = MisprintRule;
//# sourceMappingURL=MisprintRule.js.map