"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeysUtils = void 0;
const lodash_1 = require("lodash");
const models_1 = require("./../models");
const enums_1 = require("./../enums");
class KeysUtils {
    static groupKeysByName(keys) {
        return (0, lodash_1.chain)(keys).groupBy("name").map((dictionary, key) => {
            const views = (0, lodash_1.union)(...(0, lodash_1.map)(dictionary, 'views'));
            const languages = (0, lodash_1.union)(...(0, lodash_1.map)(dictionary, 'languages'));
            const item = new models_1.KeyModel(key, views, languages);
            return item;
        }).value();
    }
    static findKeysList(keys, customRegExp = [], deepSearch = enums_1.ToggleRule.disable) {
        let keysListRegExp = '';
        const mainRegExp = "(?<=(?<![A-Za-z0-9])t\\(['\"])([A-Za-z0-9_\\-. ]+)(?=['\"]|\\))";
        if (deepSearch === enums_1.ToggleRule.enable) {
            keysListRegExp = keys.map((key) => {
                const regExpForSingleKey = `(?<=[^\\w.-])${key.replace('.', '\\.')}(?=[^\\w.-])`;
                return regExpForSingleKey;
            }).join('|');
        }
        // @ts-ignore
        const customRegExpList = customRegExp.map((regexp) => {
            return `${regexp}`;
        });
        const resultKeysRegExp = [
            mainRegExp,
            ...customRegExpList
        ];
        if (deepSearch === enums_1.ToggleRule.enable) {
            resultKeysRegExp.unshift(keysListRegExp);
        }
        return new RegExp(resultKeysRegExp.join('|'), 'gm');
    }
}
exports.KeysUtils = KeysUtils;
//# sourceMappingURL=keys.js.map